==> portal-contribuinte-3.125.1.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/extrato-debito-contribuinte.sql <==
SELECT DISTINCT $[FILTROTODOSCADASTROS],
       TD.ENTIDADE,
       TD.EXERCICIO,
       TD.TIPOCADASTRO,
       TD.CADASTROGERAL,
       TD.GUIARECOLHIMENTO                              as DIVIDA,
       CAST(TD.SUBDIVIDA as NUMERIC(15, 2))             as SubDivida,
       TD.IDDEBITO,
       TDP.PARCELA,
       TSP.DESCRICAO                                    as SITUACAODEBITODESCRICAO,
       TDPR.RECEITA                                     as TRIBUTO,
       P.PESSOA,
       P.NOME                                           as NOMECONTRIBUINTE,
       P.NOMEFANTASIA,
       P.RG,
       P.INSCRICAOESTADUAL,
       P.TIPOPESSOA,
       P.CNPJ_CPF                                       AS CNPJCPFCONTRIBUINTE,
       EP.NUMERO                                        as NUMEROCONTRIBUINTE,
       EP.COMPLEMENTO                                   as COMPLEMENTOCONTRIBUINTE,
       LP.descricao                                     as LOGRADOUROCONTRIBUINTE,
       TLP.DESCRICAO                                    as TIPOLOGRADOUROCONTRIBUINTE,
       CP.DESCRICAO                                     AS CIDADECONTRIBUINTE,
       CP.UNIDADEFEDERACAO                              as UNIDADEFEDERACAOCONTRIBUINTE,
       TIPOLOG.DESCRICAO                                as TIPOLOGRADOURO,
       LOG.DESCRICAO                                    as LOGRADOURO,
       TCG.NUMERO                                       as NUMERO,
       TCG.COMPLEMENTO                                  as COMPLEMENTO,
       TCG.CEP                                          as cep,
       TSP.TipoSituacaoParcela,
       TDP.SITUACAOLEGAL,
       TD.DataPrimeiraParcela                           as DATAPRIMEIRAPARCELA,
       TD.FormaCorrecao,
       BAI.descricao                                    as bairro,
       TCM.numeroRegistro,
       TCM.atividadePrincipal,
       TCM.cadastroGeralImobiliario,
       TCM.telefone,
       CASE WHEN TD.Constituido = 'S' THEN 1 ELSE 0 END AS CONSTITUIDO,
       CASE WHEN TD.Parcelado = 'S' THEN 1 ELSE 0 END   AS PARCELADO,
       CASE WHEN TD.Reparcelado = 'S' THEN 1 ELSE 0 END AS REPARCELADO,
       tdpr.valor                                       as ValorPrincipal,
       TDP.DATAVENCIMENTO,
       TDP.DATALANCAMENTO,
       TDP.DATASITUACAO                                    DATAMOVIMENTO,
       TDP.IDPROTESTO,
       COALESCE(CASE
                    WHEN tsp.tiposituacaoparcela = 2 THEN
                        SUM(tpd.valorpago) OVER(PARTITION BY TDPR.IDDEBITOPARCELARECEITA)
                    ELSE 0 END, 0)                      AS VALORPAGO,
       TGR.DESCRICAO                                    AS DESCRICAODIVIDA,
       sigla_situacao_parcela(TSP.SIGLA, TD.PARCELADO, TD.REPARCELADO, TDP.SITUACAOLEGAL,
                              TDP.IDPROTESTO)           as situacaodebitosigla,
       TP.EXERCICIOPAGAMENTO,
       TD.IDPARCELAMENTO,
       COALESCE(SUM(TPD.VALORJUROS) OVER(PARTITION BY TDPR.IDDEBITOPARCELARECEITA), 0) as VALORJUROSPAGAMENTO,
       COALESCE(SUM(TPD.VALORMULTA) OVER(PARTITION BY TDPR.IDDEBITOPARCELARECEITA), 0) as VALORMULTAPAGAMENTO,
       COALESCE(SUM(TPD.VALORCORRECAO) OVER(PARTITION BY TDPR.IDDEBITOPARCELARECEITA), 0) as VALORCORRECAOPAGAMENTO,
       COALESCE(SUM(TPD.VALORDESCONTO) OVER(PARTITION BY TDPR.IDDEBITOPARCELARECEITA), 0) as VALORDESCONTOPAGAMENTO,
       TCI.INSCRICAOCADASTRAL,
       TCI.QUADRICULA_INSCRICAOCADASTRAL                as QUADRICULA,
       TCI.DISTRITO_INSCRICAOCADASTRAL                  as DISTRITO,
       TS.SETOR,
       TSQ.QUADRA,
       TCI.LOTE_INSCRICAOCADASTRAL                      as LOTEINSCRICAOCADASTRAL,
       TCI.UNIDADE_INSCRICAOCADASTRAL                   as UNIDADE,
       TCI.COMPLEMENTOLOTE,
       TPA.NUMEROCONTRATO,
       TPA.ANOCONTRATO
FROM TRIBDEBITO TD
         INNER JOIN TRIBDEBITOPARCELA TDP ON TD.ENTIDADE = TDP.ENTIDADE
    AND TD.EXERCICIO = TDP.EXERCICIO
    AND TD.TIPOCADASTRO = TDP.TIPOCADASTRO
    AND TD.CADASTROGERAL = TDP.CADASTROGERAL
    AND TD.GUIARECOLHIMENTO = TDP.GUIARECOLHIMENTO
    AND TD.SUBDIVIDA = TDP.SUBDIVIDA
         LEFT JOIN TRIBPARCELAMENTO TPA ON TPA.IDPARCELAMENTO = coalesce(TD.IDPARCELAMENTO, TD.IDREPARCELAMENTO)
         LEFT JOIN TRIBSITUACAOPARCELA TSP ON TSP.SITUACAOPARCELA = TDP.SITUACAODEBITO
         LEFT JOIN TRIBTIPOSITUACAOPARCELA TTSP ON TTSP.TIPOSITUACAOPARCELA = TSP.TIPOSITUACAOPARCELA
         LEFT JOIN TRIBGUIARECOLHIMENTO TGR ON TGR.ENTIDADE = TD.ENTIDADE
    AND TGR.EXERCICIO = TD.EXERCICIO
    AND TGR.GUIARECOLHIMENTO = TD.GUIARECOLHIMENTO
         LEFT JOIN TRIBDEBITOPARCELARECEITA TDPR ON TDP.ENTIDADE = TDPR.ENTIDADE
    AND TDP.EXERCICIO = TDPR.EXERCICIO
    AND TDP.TIPOCADASTRO = TDPR.TIPOCADASTRO
    AND TDP.CADASTROGERAL = TDPR.CADASTROGERAL
    AND TDP.GUIARECOLHIMENTO = TDPR.GUIARECOLHIMENTO
    AND TDP.SUBDIVIDA = TDPR.SUBDIVIDA
    AND TDP.PARCELA = TDPR.PARCELA
    	 LEFT JOIN tribpagamentodebito TPD ON TPD.IDDEBITOPARCELARECEITA = TDPR.IDDEBITOPARCELARECEITA
    AND (TPD.ESTORNO IS NULL OR TPD.ESTORNO = 'N')
    AND (TPD.valordevolvido IS NULL OR TPD.valordevolvido = 0)
         LEFT JOIN TRIBPAGAMENTOBLOQUETO TPB ON TPB.IDPAGAMENTOBLOQUETO = TPD.IDPAGAMENTOBLOQUETO
         LEFT JOIN TRIBPAGAMENTO TP ON TPB.ENTIDADE = TP.ENTIDADE
    AND TPB.EXERCICIOPAGAMENTO = TP.EXERCICIOPAGAMENTO
    AND TPB.PAGAMENTO = TP.PAGAMENTO
         LEFT JOIN TRIBCADASTROGERAL TCG ON TCG.TIPOCADASTRO = TD.TIPOCADASTRO
    AND TCG.CADASTROGERAL = TD.CADASTROGERAL
         LEFT JOIN TRIBCADASTROIMOBILIARIO TCI ON TCG.IDKEY = TCI.TRIBCADASTROGERAL_IDKEY
         LEFT JOIN TRIBCADASTROMOBILIARIO TCM ON TCG.IDKEY = TCM.TRIBCADASTROGERAL_IDKEY
         LEFT JOIN TRIBSETOR TS ON TCI.TRIBSETOR_IDKEY = TS.IDKEY
         LEFT JOIN TRIBSETORQUADRA TSQ ON TCI.TRIBSETOR_IDKEY = TSQ.TRIBSETOR_IDKEY
    AND TCI.QUADRA_INSCRICAOCADASTRAL = TSQ.QUADRA
         LEFT JOIN LOGRADOURO LOG ON TCG.LOGRADOURO_IDKEY = LOG.IDKEY
         LEFT JOIN TIPOLOGRADOURO TIPOLOG ON LOG.TIPOLOGRADOURO = TIPOLOG.TIPOLOGRADOURO
         LEFT JOIN PESSOA P ON P.PESSOA = TCG.PESSOA
         LEFT JOIN ENDERECOPESSOA EP ON P.PESSOA = EP.PESSOA AND EP.SEQUENCIA = P.SEQUENCIAENDERECO
         LEFT JOIN LOGRADOURO LP ON EP.LOGRADOURO_IDKEY = LP.IDKEY
         LEFT JOIN TIPOLOGRADOURO TLP ON LP.TIPOLOGRADOURO = TLP.TIPOLOGRADOURO
         LEFT JOIN CIDADE CP ON EP.CIDADE = CP.CIDADE
         LEFT JOIN BAIRRO BAI ON BAI.BAIRRO = TCG.BAIRRO and BAI.CIDADE = CP.CIDADE
  WHERE

==> portal-contribuinte-3.163.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/extrato-debito-contribuinte.sql <==
SELECT DISTINCT $[FILTROTODOSCADASTROS],
       TD.ENTIDADE,
       TD.EXERCICIO,
       TD.TIPOCADASTRO,
       TD.CADASTROGERAL,
       TD.GUIARECOLHIMENTO                              as DIVIDA,
       CAST(TD.SUBDIVIDA as NUMERIC(15, 2))             as SubDivida,
       TD.IDDEBITO,
       TDP.PARCELA,
       TSP.DESCRICAO                                    as SITUACAODEBITODESCRICAO,
       TDPR.RECEITA                                     as TRIBUTO,
       P.PESSOA,
       P.NOME                                           as NOMECONTRIBUINTE,
       P.NOMEFANTASIA,
       P.RG,
       P.INSCRICAOESTADUAL,
       P.TIPOPESSOA,
       P.CNPJ_CPF                                       AS CNPJCPFCONTRIBUINTE,
       EP.NUMERO                                        as NUMEROCONTRIBUINTE,
       EP.COMPLEMENTO                                   as COMPLEMENTOCONTRIBUINTE,
       LP.descricao                                     as LOGRADOUROCONTRIBUINTE,
       TLP.DESCRICAO                                    as TIPOLOGRADOUROCONTRIBUINTE,
       CP.DESCRICAO                                     AS CIDADECONTRIBUINTE,
       CP.UNIDADEFEDERACAO                              as UNIDADEFEDERACAOCONTRIBUINTE,
       TIPOLOG.DESCRICAO                                as TIPOLOGRADOURO,
       LOG.DESCRICAO                                    as LOGRADOURO,
       TCG.NUMERO                                       as NUMERO,
       TCG.COMPLEMENTO                                  as COMPLEMENTO,
       TCG.CEP                                          as cep,
       TSP.TipoSituacaoParcela,
       TDP.SITUACAOLEGAL,
       TD.DataPrimeiraParcela                           as DATAPRIMEIRAPARCELA,
       TD.FormaCorrecao,
       BAI.descricao                                    as bairro,
       TCM.numeroRegistro,
       TCM.atividadePrincipal,
       TCM.cadastroGeralImobiliario,
       TCM.telefone,
       CASE WHEN TD.Constituido = 'S' THEN 1 ELSE 0 END AS CONSTITUIDO,
       CASE WHEN TD.Parcelado = 'S' THEN 1 ELSE 0 END   AS PARCELADO,
       CASE WHEN TD.Reparcelado = 'S' THEN 1 ELSE 0 END AS REPARCELADO,
       tdpr.valor                                       as ValorPrincipal,
       TDP.DATAVENCIMENTO,
       TDP.DATALANCAMENTO,
       TDP.DATASITUACAO                                    DATAMOVIMENTO,
       TDP.IDPROTESTO,
       COALESCE(CASE
                    WHEN tsp.tiposituacaoparcela = 2 THEN
                        SUM(tpd.valorpago) OVER(PARTITION BY TDPR.IDDEBITOPARCELARECEITA)
                    ELSE 0 END, 0)                      AS VALORPAGO,
       TGR.DESCRICAO                                    AS DESCRICAODIVIDA,
       sigla_situacao_parcela(TSP.SIGLA, TD.PARCELADO, TD.REPARCELADO, TDP.SITUACAOLEGAL,
                              TDP.IDPROTESTO)           as situacaodebitosigla,
       TP.EXERCICIOPAGAMENTO,
       TD.IDPARCELAMENTO,
       COALESCE(SUM(TPD.VALORJUROS) OVER(PARTITION BY TDPR.IDDEBITOPARCELARECEITA), 0) as VALORJUROSPAGAMENTO,
       COALESCE(SUM(TPD.VALORMULTA) OVER(PARTITION BY TDPR.IDDEBITOPARCELARECEITA), 0) as VALORMULTAPAGAMENTO,
       COALESCE(SUM(TPD.VALORCORRECAO) OVER(PARTITION BY TDPR.IDDEBITOPARCELARECEITA), 0) as VALORCORRECAOPAGAMENTO,
       COALESCE(SUM(TPD.VALORDESCONTO) OVER(PARTITION BY TDPR.IDDEBITOPARCELARECEITA), 0) as VALORDESCONTOPAGAMENTO,
       TCI.INSCRICAOCADASTRAL,
       TCI.QUADRICULA_INSCRICAOCADASTRAL                as QUADRICULA,
       TCI.DISTRITO_INSCRICAOCADASTRAL                  as DISTRITO,
       TS.SETOR,
       TSQ.QUADRA,
       TCI.LOTE_INSCRICAOCADASTRAL                      as LOTEINSCRICAOCADASTRAL,
       TCI.UNIDADE_INSCRICAOCADASTRAL                   as UNIDADE,
       TCI.COMPLEMENTOLOTE,
       TPA.NUMEROCONTRATO,
       TPA.ANOCONTRATO,
       TCI.QUADRA_DESCR                                 as quadraFiscalizacao,
       TCI.LOTE_DESCR                                   as loteFiscalizacao
FROM TRIBDEBITO TD
         INNER JOIN TRIBDEBITOPARCELA TDP ON TD.ENTIDADE = TDP.ENTIDADE
    AND TD.EXERCICIO = TDP.EXERCICIO
    AND TD.TIPOCADASTRO = TDP.TIPOCADASTRO
    AND TD.CADASTROGERAL = TDP.CADASTROGERAL
    AND TD.GUIARECOLHIMENTO = TDP.GUIARECOLHIMENTO
    AND TD.SUBDIVIDA = TDP.SUBDIVIDA
         LEFT JOIN TRIBPARCELAMENTO TPA ON TPA.IDPARCELAMENTO = coalesce(TD.IDPARCELAMENTO, TD.IDREPARCELAMENTO)
         LEFT JOIN TRIBSITUACAOPARCELA TSP ON TSP.SITUACAOPARCELA = TDP.SITUACAODEBITO
         LEFT JOIN TRIBTIPOSITUACAOPARCELA TTSP ON TTSP.TIPOSITUACAOPARCELA = TSP.TIPOSITUACAOPARCELA
         LEFT JOIN TRIBGUIARECOLHIMENTO TGR ON TGR.ENTIDADE = TD.ENTIDADE
    AND TGR.EXERCICIO = TD.EXERCICIO
    AND TGR.GUIARECOLHIMENTO = TD.GUIARECOLHIMENTO
         INNER JOIN TRIBDEBITOPARCELARECEITA TDPR ON TDP.ENTIDADE = TDPR.ENTIDADE
    AND TDP.EXERCICIO = TDPR.EXERCICIO
    AND TDP.TIPOCADASTRO = TDPR.TIPOCADASTRO
    AND TDP.CADASTROGERAL = TDPR.CADASTROGERAL
    AND TDP.GUIARECOLHIMENTO = TDPR.GUIARECOLHIMENTO
    AND TDP.SUBDIVIDA = TDPR.SUBDIVIDA
    AND TDP.PARCELA = TDPR.PARCELA
    	 LEFT JOIN tribpagamentodebito TPD ON TPD.IDDEBITOPARCELARECEITA = TDPR.IDDEBITOPARCELARECEITA
    AND (TPD.ESTORNO IS NULL OR TPD.ESTORNO = 'N')
    AND (TPD.valordevolvido IS NULL OR TPD.valordevolvido = 0)
         LEFT JOIN TRIBPAGAMENTOBLOQUETO TPB ON TPB.IDPAGAMENTOBLOQUETO = TPD.IDPAGAMENTOBLOQUETO
         LEFT JOIN TRIBPAGAMENTO TP ON TPB.ENTIDADE = TP.ENTIDADE
    AND TPB.EXERCICIOPAGAMENTO = TP.EXERCICIOPAGAMENTO
    AND TPB.PAGAMENTO = TP.PAGAMENTO
         LEFT JOIN TRIBCADASTROGERAL TCG ON TCG.TIPOCADASTRO = TD.TIPOCADASTRO
    AND TCG.CADASTROGERAL = TD.CADASTROGERAL
         LEFT JOIN TRIBCADASTROIMOBILIARIO TCI ON TCG.IDKEY = TCI.TRIBCADASTROGERAL_IDKEY
         LEFT JOIN TRIBCADASTROMOBILIARIO TCM ON TCG.IDKEY = TCM.TRIBCADASTROGERAL_IDKEY
         LEFT JOIN TRIBSETOR TS ON TCI.TRIBSETOR_IDKEY = TS.IDKEY
         LEFT JOIN TRIBSETORQUADRA TSQ ON TCI.TRIBSETOR_IDKEY = TSQ.TRIBSETOR_IDKEY
    AND TCI.QUADRA_INSCRICAOCADASTRAL = TSQ.QUADRA
         LEFT JOIN LOGRADOURO LOG ON TCG.LOGRADOURO_IDKEY = LOG.IDKEY
         LEFT JOIN TIPOLOGRADOURO TIPOLOG ON LOG.TIPOLOGRADOURO = TIPOLOG.TIPOLOGRADOURO
         LEFT JOIN PESSOA P ON P.PESSOA = TCG.PESSOA
         LEFT JOIN ENDERECOPESSOA EP ON P.PESSOA = EP.PESSOA AND EP.SEQUENCIA = P.SEQUENCIAENDERECO
         LEFT JOIN LOGRADOURO LP ON EP.LOGRADOURO_IDKEY = LP.IDKEY
         LEFT JOIN TIPOLOGRADOURO TLP ON LP.TIPOLOGRADOURO = TLP.TIPOLOGRADOURO
         LEFT JOIN CIDADE CP ON EP.CIDADE = CP.CIDADE
         LEFT JOIN BAIRRO BAI ON BAI.IDKEY = TCG.BAIRRO_IDKEY
  WHERE
